summaryrefslogtreecommitdiffstats
path: root/kmail/kmmsgpart.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmsgpart.h')
-rw-r--r--kmail/kmmsgpart.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/kmmsgpart.h b/kmail/kmmsgpart.h
index 85906af5..8ab55358 100644
--- a/kmail/kmmsgpart.h
+++ b/kmail/kmmsgpart.h
@@ -63,12 +63,12 @@ public:
TQString bodyToUnicode(const TQTextCodec* codec=0) const;
/** Returns body as decoded string. Assumes that content-transfer-encoding
- tqcontains the correct encoding. This routine is meant for binary data.
+ contains the correct encoding. This routine is meant for binary data.
No trailing 0 is appended. */
TQByteArray bodyDecodedBinary(void) const;
/** Returns body as decoded string. Assumes that content-transfer-encoding
- tqcontains the correct encoding. This routine is meant for text strings! */
+ contains the correct encoding. This routine is meant for text strings! */
TQCString bodyDecoded(void) const;
/** Sets body, encoded in the best fitting
@@ -100,8 +100,8 @@ public:
This one is for text strings, the trailing 0 is not used.
For speed reasons, prefer setBodyEncodedBinary.
- When possible (the TQCString isn't used afterwards), change setBodyEncoded(myQCString) into:
- setBodyEncodedBinary(byteArrayFromQCStringNoDetach(myQCString));
+ When possible (the TQCString isn't used afterwards), change setBodyEncoded(myTQCString) into:
+ setBodyEncodedBinary(byteArrayFromTQCStringNoDetach(myTQCString));
*/
void setBodyEncoded(const TQCString& aStr);
@@ -209,13 +209,13 @@ public:
/** Sets the part number */
void setPartSpecifier( const TQString & part ) { mPartSpecifier = part; }
/** If this part is complete (tqcontains a body) */
bool isComplete() { return (!mBody.isNull()); }
- /** Returns the parent part */
- KMMessagePart* parent() { return mParent; }
+ /** Returns the tqparent part */
+ KMMessagePart* tqparent() { return mParent; }
- /** Set the parent of this part */
+ /** Set the tqparent of this part */
void setParent( KMMessagePart* part ) { mParent = part; }
/** Returns true if the headers should be loaded */
@@ -209,13 +209,13 @@ public:
/** Sets the part number */
void setPartSpecifier( const TQString & part ) { mPartSpecifier = part; }
- /** If this part is complete (tqcontains a body) */
+ /** If this part is complete (contains a body) */
bool isComplete() { return (!mBody.isNull()); }